==> igniteui-webcomponents-maps-4.7.2.tgz: package/esm2015/lib/igc-tile-series-component.js <==
import { IgcShapeSeriesBaseComponent } from "igniteui-webcomponents-charts";
import { TileSeries } from "./TileSeries";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
/**
 * Represents a tile series class that can render imagery tiles
*/
export let IgcTileSeriesComponent = /*@__PURE__*/ (() => {
    class IgcTileSeriesComponent extends IgcShapeSeriesBaseComponent {
        createImplementation() {
            return new TileSeries();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcTileSeriesComponent._observedAttributesIgcTileSeriesComponent == null) {
                let names = getAllPropertyNames(IgcTileSeriesComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcTileSeriesComponent._observedAttributesIgcTileSeriesComponent = names;
            }
            return IgcTileSeriesComponent._observedAttributesIgcTileSeriesComponent;
        }
        static register() {
            if (!IgcTileSeriesComponent._isElementRegistered) {
                IgcTileSeriesComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcTileSeriesComponent.htmlTagName, IgcTileSeriesComponent);
            }
        }
        /**
         * Gets whether the current series shows a tile imagery.
        */
        get isTile() {
            return this.i.fh;
        }
        /**
         * The MapImagery which is used to provide the tiles for display.
        */
        get tileImagery() {
            const r = this.i.wy;
            if (r == null) {
                return null;
            }
            return r.externalObject;
        }
        set tileImagery(v) {
            v == null ? this.i.wy = null : this.i.wy = v.i;
        }
        findByName(name) {
            var baseResult = super.findByName(name);
            if (baseResult) {
                return baseResult;
            }
            if (this.tileImagery && this.tileImagery.name && this.tileImagery.name == name) {
                return this.tileImagery;
            }
            return null;
        }
        /**
         * Defers rendering of the series
        
        */
        deferredRefresh() {
            this.i.deferredRefresh();
        }
    }
    IgcTileSeriesComponent._observedAttributesIgcTileSeriesComponent = null;
    IgcTileSeriesComponent.htmlTagName = "igc-tile-series";
    IgcTileSeriesComponent._isElementRegistered = false;
    return IgcTileSeriesComponent;
})();

==> igniteui-webcomponents-maps-5.4.1.tgz: package/esm2015/lib/igc-tile-series-component.js <==
import { IgcShapeSeriesBaseComponent } from "igniteui-webcomponents-charts";
import { TileSeries } from "./TileSeries";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
/**
 * Represents a tile series class that can render imagery tiles
*/
export let IgcTileSeriesComponent = /*@__PURE__*/ (() => {
    class IgcTileSeriesComponent extends IgcShapeSeriesBaseComponent {
        createImplementation() {
            return new TileSeries();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcTileSeriesComponent._observedAttributesIgcTileSeriesComponent == null) {
                let names = getAllPropertyNames(IgcTileSeriesComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcTileSeriesComponent._observedAttributesIgcTileSeriesComponent = names;
            }
            return IgcTileSeriesComponent._observedAttributesIgcTileSeriesComponent;
        }
        static register() {
            if (!IgcTileSeriesComponent._isElementRegistered) {
                IgcTileSeriesComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcTileSeriesComponent.htmlTagName, IgcTileSeriesComponent);
            }
        }
        /**
         * Gets whether the current series shows a tile imagery.
        */
        get isTile() {
            return this.i.f3;
        }
        /**
         * The MapImagery which is used to provide the tiles for display.
        */
        get tileImagery() {
            const r = this.i.aad;
            if (r == null) {
                return null;
            }
            return r.externalObject;
        }
        set tileImagery(v) {
            v == null ? this.i.aad = null : this.i.aad = v.i;
        }
        findByName(name) {
            var baseResult = super.findByName(name);
            if (baseResult) {
                return baseResult;
            }
            if (this.tileImagery && this.tileImagery.name && this.tileImagery.name == name) {
                return this.tileImagery;
            }
            return null;
        }
        /**
         * Defers rendering of the series
        
        */
        deferredRefresh() {
            this.i.deferredRefresh();
        }
    }
    IgcTileSeriesComponent._observedAttributesIgcTileSeriesComponent = null;
    IgcTileSeriesComponent.htmlTagName = "igc-tile-series";
    IgcTileSeriesComponent._isElementRegistered = false;
    return IgcTileSeriesComponent;
})();
